@@ -1,13 +1,11 @@
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <unistd.h>
+#include "sysincludes.h"
 #include "msdos.h"
 #include "mtools.h"
 #include "patchlevel.h"
 
 const char *mversion = VERSION;
 const char *mdate = DATE;
+int	mtools_raw_tty = 1;
 
 #define DISPATCH(cmd,fn,type) if (!strcmp(name,cmd)) fn(argc, argv, type)
 
@@ -15,7 +13,13 @@ const char *mdate = DATE;
 void main(int argc,char **argv)
 {
 	char *name;
-	
+
+	/* print the version */
+	if(argc >= 2 && strcmp(argv[1], "-V") == 0) {
+		printf("Mtools version %s, dated %s\n", mversion, mdate);
+		exit(0);
+	}
+
 	if ((name = strrchr(argv[0],'/')))
 		name++;
 	else name = argv[0];
@@ -43,5 +47,6 @@ void main(int argc,char **argv)
 	DISPATCH("mtype",mcopy, 1);
 	DISPATCH("mwrite",mcopy, 0);
 	fprintf(stderr,"Unknown mtools command '%s'\n",name);
-	exit(1);
+
+	cleanup_and_exit(1);
 }
